----------------------------------------------------------
--		Alpha Maps Filter Script		--
--							--
--  Author:	Nathaniel Meyer				--
--  Email:	nate@nutty.ca				--
--  Copyright:	Nutty Productions			--
--  Website:	http://www.nutty.ca			--
--							--
--  Desc:	This script creates a series of 32	--
--		alphamaps for use in tile-based games.	--
----------------------------------------------------------


-- Includes --
require "scripts/maths"
--------------


-- Globals --
local width, height, channels = GetImage();
width = width - 1;
height = height - 1;
-------------


-- Configuration --
local maxRadius = 12;
-------------------


-- Local Members --
local theta;
local thetaAdd = 1 - ((maxRadius * maxRadius) / (width * height));
if ( thetaAdd < 0.1 ) then
	thetaAdd = 0.1;
end
local curRadius;
local x;
local y;
local r, g, b, a;
local alpha;
--------------------


--[[
	drawCircle
		@desc: Starting from the point, radiate outwards and render a circle with declining alpha value
]]
function drawCircle(point, radius)
	curRadius = 0;

	repeat
		theta = 0;
		alpha = (1 - (curRadius / radius)) * 255;

		repeat
			x = point.x + (curRadius * math.cos(math.rad(theta)));
			y = point.y + (curRadius * math.sin(math.rad(theta)));
			theta = theta + thetaAdd;

			-- Get/Set the RGB values
			SetPixel(x, y, 255, 255, 255, alpha);
		until ( theta > 360 )
		
		curRadius = curRadius + 1;
	until ( curRadius > radius )
end

--[[
	drawSquare
		@desc: Starting from the point1, render to point 2 and radiate outwards with a declining alpha value
]]
function drawSquare(point1, point2, radius)
	-- Vertical or horizontal lines?
	if ( point1.x == point2.x ) then
		-- Horizontal
		for x = 0, radius do
			alpha = (1 - (x / radius)) * 255;

			for y = point1.y, point2.y do
				if ( (point1.x + x) <= width ) then
					-- Get/Set the RGB values
					r, g, b, a = GetPixel(point1.x + x, y, false);
					SetPixel(point1.x + x, y, 255, 255, 255, math.min(alpha + a, 255));
				end

				if ( (point1.x - x) >= 0 ) then
					-- Get/Set the RGB values
					r, g, b, a = GetPixel(point1.x - x, y, false);
					SetPixel(point1.x - x, y, 255, 255, 255, math.min(alpha + a, 255));
				end
			end
		end
	else
		-- Vertical
		for y = 0, radius do
			alpha = (1 - (y / radius)) * 255;

			for x = point1.x, point2.x do
				if ( (point1.y + y) <= height ) then
					-- Get/Set the RGB values
					r, g, b, a = GetPixel(x, point1.y + y, false);
					SetPixel(x, point1.y + y, 255, 255, 255, math.min(alpha + a, 255));
				end

				if ( (point1.y - y) >= 0 ) then
					-- Get/Set the RGB values
					r, g, b, a = GetPixel(x, point1.y - y, false);
					SetPixel(x, point1.y - y, 255, 255, 255, math.min(alpha + a, 255));
				end
			end
		end
	end
end


--[[
	Corners
]]
--[[ Top Left ]]
drawCircle(Point(0, height, 0), maxRadius);
Save();

--[[ Top Right ]]
drawCircle(Point(width, height, 0), maxRadius);
Save();

--[[ Bottom Right ]]
drawCircle(Point(width, 0, 0), maxRadius);
Save();

--[[ Bottom Left ]]
drawCircle(Point(0, 0, 0), maxRadius);
Save();

--[[ Top Left, Top Right ]]
drawCircle(Point(0, height, 0), maxRadius);
drawCircle(Point(width, height, 0), maxRadius);
Save();

--[[ Top Right, Bottom Right ]]
drawCircle(Point(width, height, 0), maxRadius);
drawCircle(Point(width, 0, 0), maxRadius);
Save();

--[[ Bottom Right, Bottom Left ]]
drawCircle(Point(width, 0, 0), maxRadius);
drawCircle(Point(0, 0, 0), maxRadius);
Save();

--[[ Bottom Left, Top Left ]]
drawCircle(Point(0, 0, 0), maxRadius);
drawCircle(Point(0, height, 0), maxRadius);
Save();

--[[ Top Left, Bottom Right ]]
drawCircle(Point(0, height, 0), maxRadius);
drawCircle(Point(width, 0, 0), maxRadius);
Save();

--[[ Top Right, Bottom Left ]]
drawCircle(Point(width, height, 0), maxRadius);
drawCircle(Point(0, 0, 0), maxRadius);
Save();

--[[ Top Left, Top Right, Bottom Right ]]
drawCircle(Point(0, height, 0), maxRadius);
drawCircle(Point(width, height, 0), maxRadius);
drawCircle(Point(width, 0, 0), maxRadius);
Save();

--[[ Top Right, Bottom Right, Bottom Left ]]
drawCircle(Point(width, height, 0), maxRadius);
drawCircle(Point(width, 0, 0), maxRadius);
drawCircle(Point(0, 0, 0), maxRadius);
Save();

--[[ Bottom Right, Bottom Left, Top Left ]]
drawCircle(Point(width, 0, 0), maxRadius);
drawCircle(Point(0, 0, 0), maxRadius);
drawCircle(Point(0, height, 0), maxRadius);
Save();

--[[ Bottom Left, Top Left, Top Right ]]
drawCircle(Point(0, 0, 0), maxRadius);
drawCircle(Point(0, height, 0), maxRadius);
drawCircle(Point(width, height, 0), maxRadius);
Save();

--[[ Top Left, Top Right, Bottom Right, Bottom Left ]]
drawCircle(Point(0, height, 0), maxRadius);
drawCircle(Point(width, height, 0), maxRadius);
drawCircle(Point(width, 0, 0), maxRadius);
drawCircle(Point(0, 0, 0), maxRadius);
Save();


--[[
	Lines
]]
--[[ Top ]]
drawSquare(Point(0, height, 0), Point(width, height, 0), maxRadius);
Save();

--[[ Right ]]
drawSquare(Point(width, 0, 0), Point(width, height, 0), maxRadius);
Save();

--[[ Bottom ]]
drawSquare(Point(0, 0, 0), Point(width, 0, 0), maxRadius);
Save();

--[[ Left ]]
drawSquare(Point(0, 0, 0), Point(0, height, 0), maxRadius);
Save();

--[[ Top, Right ]]
drawSquare(Point(0, height, 0), Point(width, height, 0), maxRadius);
drawSquare(Point(width, 0, 0), Point(width, height, 0), maxRadius);
Save();

--[[ Right, Bottom ]]
drawSquare(Point(width, 0, 0), Point(width, height, 0), maxRadius);
drawSquare(Point(0, 0, 0), Point(width, 0, 0), maxRadius);
Save();

--[[ Bottom, Left ]]
drawSquare(Point(0, 0, 0), Point(width, 0, 0), maxRadius);
drawSquare(Point(0, 0, 0), Point(0, height, 0), maxRadius);
Save();

--[[ Left, Top ]]
drawSquare(Point(0, 0, 0), Point(0, height, 0), maxRadius);
drawSquare(Point(0, height, 0), Point(width, height, 0), maxRadius);
Save();

--[[ Top, Bottom ]]
drawSquare(Point(0, height, 0), Point(width, height, 0), maxRadius);
drawSquare(Point(0, 0, 0), Point(width, 0, 0), maxRadius);
Save();

--[[ Right, Left ]]
drawSquare(Point(width, 0, 0), Point(width, height, 0), maxRadius);
drawSquare(Point(0, 0, 0), Point(0, height, 0), maxRadius);
Save();

--[[ Top, Right, Bottom ]]
drawSquare(Point(0, height, 0), Point(width, height, 0), maxRadius);
drawSquare(Point(width, 0, 0), Point(width, height, 0), maxRadius);
drawSquare(Point(0, 0, 0), Point(width, 0, 0), maxRadius);
Save();

--[[ Right, Bottom, Left ]]
drawSquare(Point(width, 0, 0), Point(width, height, 0), maxRadius);
drawSquare(Point(0, 0, 0), Point(width, 0, 0), maxRadius);
drawSquare(Point(0, 0, 0), Point(0, height, 0), maxRadius);
Save();

--[[ Bottom, Left, Top ]]
drawSquare(Point(0, 0, 0), Point(width, 0, 0), maxRadius);
drawSquare(Point(0, 0, 0), Point(0, height, 0), maxRadius);
drawSquare(Point(0, height, 0), Point(width, height, 0), maxRadius);
Save();

--[[ Left, Top, Right ]]
drawSquare(Point(0, 0, 0), Point(0, height, 0), maxRadius);
drawSquare(Point(0, height, 0), Point(width, height, 0), maxRadius);
drawSquare(Point(width, 0, 0), Point(width, height, 0), maxRadius);
Save();

--[[ Top, Right, Bottom, Left ]]
drawSquare(Point(0, height, 0), Point(width, height, 0), maxRadius);
drawSquare(Point(width, 0, 0), Point(width, height, 0), maxRadius);
drawSquare(Point(0, 0, 0), Point(width, 0, 0), maxRadius);
drawSquare(Point(0, 0, 0), Point(0, height, 0), maxRadius);
Save();


--[[
	Corners + Lines
]]
--[[ Top, Bottom-Right ]]
drawSquare(Point(0, height, 0), Point(width, height, 0), maxRadius);
drawCircle(Point(width, 0, 0), maxRadius);
Save();

--[[ Top, Bottom-Left ]]
drawSquare(Point(0, height, 0), Point(width, height, 0), maxRadius);
drawCircle(Point(0, 0, 0), maxRadius);
Save();

--[[ Top, Bottom-Right, Bottom-Left ]]
drawSquare(Point(0, height, 0), Point(width, height, 0), maxRadius);
drawCircle(Point(width, 0, 0), maxRadius);
drawCircle(Point(0, 0, 0), maxRadius);
Save();

--[[ Right, Bottom-Left ]]
drawSquare(Point(width, 0, 0), Point(width, height, 0), maxRadius);
drawCircle(Point(0, 0, 0), maxRadius);
Save();

--[[ Right, Top-Left ]]
drawSquare(Point(width, 0, 0), Point(width, height, 0), maxRadius);
drawCircle(Point(0, height, 0), maxRadius);
Save();

--[[ Right, Bottom-Left, Top-Left ]]
drawSquare(Point(width, 0, 0), Point(width, height, 0), maxRadius);
drawCircle(Point(0, 0, 0), maxRadius);
drawCircle(Point(0, height, 0), maxRadius);
Save();

--[[ Bottom, Top-Left ]]
drawSquare(Point(0, 0, 0), Point(width, 0, 0), maxRadius);
drawCircle(Point(0, height, 0), maxRadius);
Save();

--[[ Bottom, Top-Right ]]
drawSquare(Point(0, 0, 0), Point(width, 0, 0), maxRadius);
drawCircle(Point(width, height, 0), maxRadius);
Save();

--[[ Bottom, Top-Left, Top-Right ]]
drawSquare(Point(0, 0, 0), Point(width, 0, 0), maxRadius);
drawCircle(Point(0, height, 0), maxRadius);
drawCircle(Point(width, height, 0), maxRadius);
Save();

--[[ Left, Top-Right ]]
drawSquare(Point(0, 0, 0), Point(0, height, 0), maxRadius);
drawCircle(Point(width, height, 0), maxRadius);
Save();

--[[ Left, Bottom-Right ]]
drawSquare(Point(0, 0, 0), Point(0, height, 0), maxRadius);
drawCircle(Point(width, 0, 0), maxRadius);
Save();

--[[ Left, Top-Right, Bottom-Right ]]
drawSquare(Point(0, 0, 0), Point(0, height, 0), maxRadius);
drawCircle(Point(width, height, 0), maxRadius);
drawCircle(Point(width, 0, 0), maxRadius);
Save();

--[[ Top, Right, Bottom-Left ]]
drawSquare(Point(0, height, 0), Point(width, height, 0), maxRadius);
drawSquare(Point(width, 0, 0), Point(width, height, 0), maxRadius);
drawCircle(Point(0, 0, 0), maxRadius);
Save();

--[[ Right, Bottom, Top-Left ]]
drawSquare(Point(width, 0, 0), Point(width, height, 0), maxRadius);
drawSquare(Point(0, 0, 0), Point(width, 0, 0), maxRadius);
drawCircle(Point(0, height, 0), maxRadius);
Save();

--[[ Bottom, Left, Top-Right ]]
drawSquare(Point(0, 0, 0), Point(width, 0, 0), maxRadius);
drawSquare(Point(0, 0, 0), Point(0, height, 0), maxRadius);
drawCircle(Point(width, height, 0), maxRadius);
Save();

--[[ Left, Top, Bottom-Right ]]
drawSquare(Point(0, 0, 0), Point(0, height, 0), maxRadius);
drawSquare(Point(0, height, 0), Point(width, height, 0), maxRadius);
drawCircle(Point(width, 0, 0), maxRadius);
Save();