----------------------------------------------------------
--		Curve Script				--
--							--
--  Author:	Nathaniel Meyer				--
--  Email:	nate@nutty.ca				--
--  Copyright:	Nutty Productions			--
--  Website:	http://www.nutty.ca			--
--							--
--  Desc:	The curve script produces a curve	--
--		between 0 and 255. At each index, the	--
--		curve lists the new luminosity offset	--
--		value to be used. In the main image,	--
--		each pixel's luminosity will be offset	--
--		based on the value stored in the curve.	--
--							--
--		Ex:					--
--		1) lumel(pixel.rgb) = 128		--
--		2) curve[128] = 140 (offset = +12)	--
--		3) pixel.rgb += 12			--
--							--
----------------------------------------------------------


-- Globals --
local width, height, channels	= GetImage();
local iWidth			= width - 1;
local iHeight			= height - 1;
local progress			= math.floor(height / 10);
-------------


-- Configuration --
SetCurve(0, 0, 55, 0, 0, 0,		-- First Point
	 255, 255, 0, 0, 255, 200);	-- Second Point
-------------------


-- Local Members --
local r, g, b;
local lumel;
local curve;
local offset;
-------------


-- Filter Image --
for y = 0, iHeight do
	for x = 0, iWidth do
		-- Get the pixel, calculate the lumel, and obtain the curve value
		r, g, b = GetPixel(x, y);
		lumel = (r + g + b) / 3;
		curve = GetCurve(lumel);

		-- Calculate the offset
		offset = curve - lumel;

		-- Upper boundary check
		r = math.min(r + offset, 255);
		g = math.min(g + offset, 255);
		b = math.min(b + offset, 255);

		-- Lower boundary check
		r = math.max(r, 0);
		g = math.max(g, 0);
		b = math.max(b, 0);

		-- Set the pixel
		SetPixel(x, y, r, g, b);

		-- Update Progress
		if math.mod(y, progress) == 0 then
			SetProgress((y / height) * 100);
		end;
	end
end
