----------------------------------------------------------
--		Sample Filter Script			--
--							--
--  Author:	Nathaniel Meyer				--
--  Email:	nate@nutty.ca				--
--  Copyright:	Nutty Productions			--
--  Website:	http://www.nutty.ca			--
--							--
--  Desc:	This is a sample script that acquires	--
--		image information and reverses the	--
--		colour order.				--
--							--
----------------------------------------------------------


-- Includes --
require "scripts/image"
--------------


-- Globals --
local width, height, channels	= GetImage();
local iWidth			= width - 1;
local iHeight			= height - 1;
local progress			= math.floor(height / 10);
local progress2			= math.floor(width / 10);
local blurImage			= {};
-------------


-- Configuration --
local opacity = 0.0;
-------------------


-- Local Members --
local total	= Colour(0, 0, 0, 0);
local src	= Colour(0, 0, 0, 0);
local dst	= Colour(0, 0, 0, 0);
local colour	= Colour(0, 0, 0, 0);
local r, g, b;
local iX;
local index;
--------------------


function blur (radius)
	-- Fast Blur - Motion Blur: Horizontal + Vertical
	-- Dx,y = Dx-1,y + c / (2k + 1) * [Sx+1,y - Sx-r-1,y]

	-- Compute k
	local k = 1 / (2 * radius + 1);

	-- Horizontal Blur
	for y = 0, iHeight do
		-- Local Members
		blurImage[y]	= {};
		total.r		= 0;
		total.g		= 0;
		total.b		= 0;

		-- Calculate the first part (along the edges)
		for x = 0, radius do
			r, g, b = GetPixel(x, y);
			total.r = total.r + r;
			total.g = total.g + g;
			total.b = total.b + b;
		end

		-- For the entire scanline, set the totals
		for x = 0, iWidth do
			-- Check when done with the beginning
			if ( x > radius ) then
				r, g, b = GetPixel(x - radius - 1, y);
				total.r = total.r - r;
				total.g = total.g - g;
				total.b = total.b - b;
			end

			-- Calculate the difference
			if ( (x + radius) < width ) then
				r, g, b = GetPixel(x + radius, y);
				total.r = total.r + r;
				total.g = total.g + g;
				total.b = total.b + b;
			end

			-- Set the image
			iX = x * 3;
			blurImage[y][iX + 0] = k * total.r;
			blurImage[y][iX + 1] = k * total.g;
			blurImage[y][iX + 2] = k * total.b;
		end

		-- Update Progress from 0 to 33
		if math.mod(y, progress) == 0 then
			SetProgress((y / height) * 33);
		end;
	end

	-- Vertical Blur
	for x = 0, iWidth do
		-- Local Members
		iX	= x * 3;
		total.r	= 0;
		total.g	= 0;
		total.b	= 0;

		-- Calculate the first part (along the edges)
		for y = 0, radius do
			total.r = total.r + blurImage[y][iX + 0];
			total.g = total.g + blurImage[y][iX + 1];
			total.b = total.b + blurImage[y][iX + 2];
		end

		-- For the entire scanline, set the totals
		for y = 0, iHeight do
			-- Check when done with the beginning
			if ( y > radius ) then
				index = y - radius - 1;
				total.r = total.r - blurImage[index][iX + 0];
				total.g = total.g - blurImage[index][iX + 1];
				total.b = total.b - blurImage[index][iX + 2];
			end

			-- Calculate the difference
			if ( (y + radius) < height ) then
				index = y + radius;
				total.r = total.r + blurImage[index][iX + 0];
				total.g = total.g + blurImage[index][iX + 1];
				total.b = total.b + blurImage[index][iX + 2];
			end

			-- Set the image
			blurImage[y][iX + 0] = (blurImage[y][iX + 0] + k * total.r) / 2;
			blurImage[y][iX + 1] = (blurImage[y][iX + 1] + k * total.g) / 2;
			blurImage[y][iX + 2] = (blurImage[y][iX + 2] + k * total.b) / 2;
		end

		-- Update Progress from 33 to 66
		if math.mod(x, progress2) == 0 then
			SetProgress(33 + (x / width) * 33);
		end;
	end

	-- Slow Convolution Blur --
	--[[for iY = y - radius, y + radius do
		if ( (iY >= 0) and (iY < height) ) then
			for iX = x - radius, x + radius do
				if ( (iX >= 0) and (iX < width) ) then
					local r, g, b = GetPixel(iX, iY);

					colour.r = colour.r + r;
					colour.g = colour.g + g;
					colour.b = colour.b + b;

					count = count + 1;
				end
			end
		end
	end]]
end


-- Apply Blur
blur(10);


-- Apply Glow --
for y = 0, iHeight do
	for x = 0, iWidth do
		-- Update Image Data
		dst.r, dst.g, dst.b = GetPixel(x, y);

		iX = x * 3;
		src.r = blurImage[y][iX + 0];
		src.g = blurImage[y][iX + 1];
		src.b = blurImage[y][iX + 2];
		imgColourCheck(src);

		--SetPixel(x, y, src.r, src.g, src.b);

		-- Blur the image (convolution)
		--local colourBlur = blur(x, y, 20);

		-- Screen blend the two
		--colour = imgScreen(dst, src);
		imgScreen(dst, src, colour);

		SetPixel(x, y, colour.r, colour.g, colour.b);

		-- Update Progress from 66 to 100
		if math.mod(y, progress) == 0 then
			SetProgress(66 + (y / height) * 34);
		end;
	end
end
