----------------------------------------------------------
--		Sample Filter Script			--
--							--
--  Author:	Nathaniel Meyer				--
--  Email:	nate@nutty.ca				--
--  Copyright:	Nutty Productions			--
--  Website:	http://www.nutty.ca			--
--							--
--  Desc:	This is a sample script that acquires	--
--		image information and reverses the	--
--		colour order.				--
--							--
--  Functions:	GetImage()				--
--		- Returns image information		--
--			Width in pixels			--
--			Height in pixels		--
--			Channels (3 = RGB, 4 = RGBA)	--
--							--
--		GetPixel(x, y, copy = true)		--
--		- Return the RGB/A value from (x,y)	--
--		- If copy is false, retrieve the pixel	--
--		  from the destination image (image 	--
--		  that gets modified with SetPixel).	--
--		  If true (default), retrieve the pixel	--
--		  from the source image (untouched).
--							--
--		SetPixel(x, y, r, g, b, a)		--
--		- Set the RGB/A value at (x, y)		--
--		- You can optionally edit the first	--
--		  few channels, ie: SetPixel(x, y, r)	--
--							--
--		SetCurve(x1, y1,		--
--			 x2, y2,		--
--			 cX1, cY1,		--
--			 cX2, cY2)		--
--		- Creates a bezier path from Point1 to	--
--		  Point2 with specified controls	--
--		  points. The function parameters can	--
--		  be looped to provide a more custom	--
--		  curve.				--
--							--
--		GetCurve(luminosity)			--
--		- Retrieve the curve value at the	--
--		  specified luminosity rating (0 - 255)	--
--							--
--		Progress(percent)			--
--		- Update the secondary progress bar to	--
--		  notify the app how much of the LUA	--
--		  script is completed.			--
--							--
--		Save()					--
--		- This will output the image with a	--
--		  sequence number. This is useful for	--
--		  creating animations.			--
--		- When used, the default image that	--
--		  normally gets written will be		--
--		  ignored.				--
----------------------------------------------------------


-- Local Members --
local width, height, channels	= GetImage();
local iWidth			= width - 1;
local iHeight			= height - 1;
local progress			= math.floor(height / 10);
local r, g, b, a;
local threshold = 20;
local alphaThreshold = 10;
-------------


-- Filter Image --
for y = 0, iHeight do
	for x = 0, iWidth do
		-- Update Image Data
		if channels == 4 then
			r, g, b, a = GetPixel(x, y);

			if ( (g > (r + threshold)) and (g > (b + threshold)) ) then
				SetPixel(x, y, 255, 255, 255, 0);
			--elseif ( (g > (r + alphaThreshold)) and (g > (b + alphaThreshold)) ) then
				--SetPixel(x, y, r, g, b, ((1.0 - (g - math.max(r, b)) / alphaThreshold)) * 255 );
			else
				SetPixel(x, y, r, g, b, a);
			end
		end

		-- Update Progress
		if math.mod(y, progress) == 0 then
			SetProgress((y / height) * 100);
		end;
	end
end
