----------------------------------------------------------
--		Lighting Filter Script			--
--							--
--  Author:	Nathaniel Meyer				--
--  Email:	nate@nutty.ca				--
--  Copyright:	Nutty Productions			--
--  Website:	http://www.nutty.ca			--
--							--
--  Desc:	This script adds lighting to the image	--
--		at a specified point. Configure the	--
--		script by setting the options below.	--
--							--
----------------------------------------------------------


-- Includes --
require "scripts/maths"
--------------


-- Globals --
local width, height, channels	= GetImage();
local iWidth			= width - 1;
local iHeight			= height - 1;
local progress			= math.floor(height / 10);
--------------


--[[
	Light
		@desc: Light source
]]
function Light (x, y, z, intensity, red, green, blue)
	return { x = x, y = y, z = z, i = intensity, r = red, g = green, b = blue };
end


-- Configuration --
local lightSource = {
			-- Light 1
			Light(width / 2, height / 2, 100,
				0.0,
				0.2, 0.4, 0.6),

			--[[ Light 2
			Light(width / 2, height / 2, 100,
				0.6,
				0.1, 1.0, 0.1),

			-- Light 3
			Light(width / 3, height / 3, 300,
				1,
				0.1, 0.1, 1.0)]]
		    };
-------------------


-- Local Members --
local lightVec		= Point(0, 0, 0);
local normal		= Point(0, 0, 1);
local diffuse		= Point(0, 0, 0);
local r, g, b;
local intensity;
-------------------


--[[
	Modify the image for each light source
]]
for a = 0, 10 do
for y = 0, iHeight do
	for x = 0, iWidth do
		r, g, b = GetPixel(x, y);
		diffuse.x = 0;
		diffuse.y = 0;
		diffuse.z = 0;

		-- Factor in each light source
		for i, light in ipairs(lightSource) do
			-- Calculate Vector
			lightVec.x = light.x - x;
			lightVec.y = light.y - y;
			lightVec.z = light.z;
			normalize(lightVec);

			-- Calculate the dot product
			intensity = dot(lightVec, normal) * (light.i + a);

			-- Add diffuse lighting
			diffuse.x = diffuse.x + (r * intensity * light.r);
			diffuse.y = diffuse.y + (g * intensity * light.g);
			diffuse.z = diffuse.z + (b * intensity * light.b);
		end

		-- Upper boundary check
		diffuse.x = math.min(diffuse.x, 255);
		diffuse.y = math.min(diffuse.y, 255);
		diffuse.z = math.min(diffuse.z, 255);

		-- Lower boundary check
		diffuse.x = math.max(diffuse.x, 0);
		diffuse.y = math.max(diffuse.y, 0);
		diffuse.z = math.max(diffuse.z, 0);

		-- Set the pixel
		SetPixel(x, y, diffuse.x, diffuse.y, diffuse.z);

		-- Update Progress
		if math.mod(y, progress) == 0 then
			SetProgress((y / height) * 100);
		end;
	end
end
Save();
end