----------------------------------------------------------
--		Refract Filter Script			--
--							--
--  Author:	Nathaniel Meyer				--
--  Email:	nate@nutty.ca				--
--  Copyright:	Nutty Productions			--
--  Website:	http://www.nutty.ca			--
--							--
--  Desc:	This script takes four parameters	--
--		required for snell's law and applies	--
--		refraction to the image with a bit of	--
--		a twist.				--
--							--
----------------------------------------------------------


-- Includes --
require "scripts/maths"
--------------


-- Globals --
local width, height, channels	= GetImage();
-------------


-- Configuration --
local normal		= Point(0, 0, 1);
local n1		= 0.5;
local n2		= 0.35;
local offsetW		= width / 10;
local offsetH		= height / 10;
-------------------


-- Local Memebrs --
local iWidth		= width - offsetW;
local iHeight		= height - offsetH;
local progress		= math.floor(iHeight / 10);
local incident		= Point(0, 0, 1);
local result;
local r, g, b;
-------------------


-- Filter Image --
for y = offsetH, iHeight do
	for x = offsetW, iWidth do
		-- Calculate the incidence
		incident.x = 0.5 - ((x - offsetW) / iWidth);
		incident.y = 0.5 - ((y - offsetH) / iHeight);
		incident.z = 1;
		normalize(incident);

		-- Get the refracted vector
		result = refract(normal, incident, n1, n2);
		result.x = x + (result.x * offsetW) * math.cos(math.rad(x - offsetW));
		result.y = y + (result.y * offsetH) * math.sin(math.rad(y - offsetH));

		-- Use the refracted vector to ge the (R,G,B) values
		if ( (result.x) >= 0 and (result.x < width) and
		     (result.y) >= 0 and (result.y < height) ) then
			r, g, b = GetPixel(result.x, result.y);

			-- Set this pixel
			SetPixel(x, y, r, g, b);
		end

		-- Update Progress
		if math.mod(y - offsetH, progress) == 0 then
			SetProgress(((y - offsetH) / iHeight) * 100);
		end;
	end
end

-- Create a border --
for x = offsetW, iWidth do
	SetPixel(x, offsetH, 0, 0, 0);
	SetPixel(x, iHeight, 0, 0, 0);
end
for y = offsetH, iHeight do
	SetPixel(offsetW, y, 0, 0, 0);
	SetPixel(iWidth, y, 0, 0, 0);
end
---------------------
