----------------------------------------------------------
--		Ripple Filter Script			--
--							--
--  Author:	Nathaniel Meyer				--
--  Email:	nate@nutty.ca				--
--  Copyright:	Nutty Productions			--
--  Website:	http://www.nutty.ca			--
--							--
--  Desc:	This script simulates a sinusoidal wave	--
--		traveling through the image.		--
--							--
----------------------------------------------------------


-- Includes --
require "scripts/maths"
--------------


-- Globals --
local width, height, channels	= GetImage();
local middleX			= width / 2;
local middleY			= height / 2;
-------------


-- CONFIGURATION --
local resolution	= height - 1;
local numCircle		= 10;
local spiralDistance	= 0.2;
local radius		= 100;
local edgeThickness	= 25;
-------------------


-- Local Members --
local thickness		= edgeThickness / 2;
local lightPos		= Point(width / 2, height / 2, 500);
local diffuse		= Point(0, 0, 0);
local angle;
local x2;
local y2;
local smooth;
local t;
local r, g, b;
-------------------


-- Filter Image --
for i = 0, numCircle do
	for j = 0, resolution do
			angle = (j / resolution) * 360;

			x2 = middleX + i * radius * math.cos(math.rad(angle));
			y2 = middleY + i * radius * math.sin(math.rad(angle));

			-- Draw the pixels
			for k = -thickness, thickness, 1 do
				for l = -thickness, thickness, 1 do
					if ( ((x2 + k) >= 0) and ((x2 + k) < (width-1)) and
					     ((y2 + l) >= 0) and ((y2 + l) < (height-1)) ) then
						smooth = (k / thickness) * 3.14159265;
						t = math.cos(smooth) * 0.05;

						r, g, b = GetPixel(x2 + k, y2 + l);

						r = r - r * t;
						g = g - g * t;
						b = b - b * t;

						r = math.max(r, 0);
						g = math.max(g, 0);
						b = math.max(b, 0);

						r = math.min(r, 255);
						g = math.min(g, 255);
						b = math.min(b, 255);

						-- Set the RGB values
						SetPixel(x2 - k, y2 - l, r, g, b);			
					end
				end
			end
	end

	-- Update Progress
	SetProgress((i / numCircle) * 100);
end
