----------------------------------------------------------
--		Spiral Filter Script			--
--							--
--  Author:	Nathaniel Meyer				--
--  Email:	nate@nutty.ca				--
--  Copyright:	Nutty Productions			--
--  Website:	http://www.nutty.ca			--
--							--
--  Desc:	This script creates a spiral starting	--
--		from the center of the image.		--
--							--
----------------------------------------------------------


-- Globals --
local width, height, channels = GetImage();
-------------


-- Configuration --
local spiralDistance	= 0.2;
local spiralThickness	= 4;
-------------------


-- Local Members --
local x		= width / 2;
local y		= height / 2;
local index	= 0;
local thickness	= spiralThickness / 2;
local anim	= 0;
local numFrame	= 30;
local x2;
local y2;
local r, g, b;
--------------------


--[[
	Spiral
		@desc: Starting from the center, spiral outwards with an animation
]]
for i = 1, numFrame do
	index = 0;

	repeat
		x2 = 0 + (index * spiralDistance) * math.cos(math.rad(math.mod(index, 360) + anim));
		y2 = 0 + (index * spiralDistance) * math.sin(math.rad(math.mod(index, 360) + anim));
		index = index + 1;

		-- Get the RGB values
		r, g, b = GetPixel(x + x2, y + y2);

		-- Draw the pixels
		for i = -thickness, thickness, 1 do
			for j = -thickness, thickness, 1 do
				-- Set the RGB values
				SetPixel(x + x2 + i, y + y2 + j, 0, 0, 0);
			end
		end
	until (x2 > width) and (y2 > height)

	-- Save image
	Save();

	-- Adjust next spiral
	anim = anim - (360 / numFrame);

	-- Update Progress
	SetProgress((i / numFrame) * 100);
end
